# distributionsGB

This package contains the Gaussian and Binomial class, and their parent class: Distribution

# Installation

Install this library directly into an activated virtual environment:

    $ pip install distributionsGB
    
